==> jc-1.4.0.tar.gz: soot/toolkits/graph/PseudoTopologicalOrderer.h <==
// public class soot.toolkits.graph.PseudoTopologicalOrderer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b9367d2347eb17f soot_toolkits_graph_PseudoTopologicalOrderer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_graph_PseudoTopologicalOrderer_H_
#define _JC_soot_toolkits_graph_PseudoTopologicalOrderer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_refs	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_refs;
typedef struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_nonrefs	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$refs	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$refs;
typedef struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$nonrefs	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$nonrefs;
typedef struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$object;

typedef struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$fields_struct	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$fields_struct;
typedef const struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$vmethods	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$vmethods;
typedef const struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtable	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtable;
typedef const struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtype	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtype;

// Class fields structure
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$fields_struct {
	struct _jc_java_lang_Object$object	*GRAY;
	jboolean	REVERSE;
};
extern _jc_soot_toolkits_graph_PseudoTopologicalOrderer$fields_struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$class_fields;

// Constructors
extern void _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *);
extern void _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, jboolean);

// Virtual methods
extern struct _jc_java_util_LinkedList$object *_jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$computeOrder$e99ef79fd26f3ec8(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, struct _jc_object *);
extern jboolean _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$isReverseOrder$b4008fcd9aa94bc0(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *);
extern struct _jc_object *_jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$newList$4c736451834ee04d(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, struct _jc_object *);
extern void _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$setReverseOrder$f411ccc2da2c0b4c(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, jboolean);
extern void _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$visitNode$76904f2e0e29deb5(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method_info$computeOrder$e99ef79fd26f3ec8;
extern _jc_method _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method_info$isReverseOrder$b4008fcd9aa94bc0;
extern _jc_method _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method_info$newList$4c736451834ee04d;
extern _jc_method _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method_info$setReverseOrder$f411ccc2da2c0b4c;
extern _jc_method _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method_info$visitNode$76904f2e0e29deb5;

// Static methods
extern void _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$vmethods {
	struct _jc_java_util_LinkedList$object	*(*computeOrder$e99ef79fd26f3ec8)(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, struct _jc_object *);
	jboolean	(*isReverseOrder$b4008fcd9aa94bc0)(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *);
	struct _jc_object	*(*newList$4c736451834ee04d)(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, struct _jc_object *);
	void	(*setReverseOrder$f411ccc2da2c0b4c)(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, jboolean);
	void	(*visitNode$76904f2e0e29deb5)(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$vmethods	soot_toolkits_graph_PseudoTopologicalOrderer;
};

// Vtype
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_refs {
	struct _jc_object	*stmtToColor;
	struct _jc_java_util_LinkedList$object	*order;
	struct _jc_object	*graph;
	_jc_int_array	*indexStack;
	_jc_object_array	*stmtStack;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$refs {
    _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_refs	soot_toolkits_graph_PseudoTopologicalOrderer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_nonrefs {
	jboolean	mIsReversed;
	jint	last;
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_nonrefs	soot_toolkits_graph_PseudoTopologicalOrderer;
};

// Object instance structure
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object {
	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtype	*vtype;
	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtype _jc_soot_toolkits_graph_PseudoTopologicalOrderer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_PseudoTopologicalOrderer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_PseudoTopologicalOrderer$class_object;

#endif	/* _JC_soot_toolkits_graph_PseudoTopologicalOrderer_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/graph/PseudoTopologicalOrderer.h <==
// public class soot.toolkits.graph.PseudoTopologicalOrderer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b9367d2347eb17f soot_toolkits_graph_PseudoTopologicalOrderer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_graph_PseudoTopologicalOrderer_H_
#define _JC_soot_toolkits_graph_PseudoTopologicalOrderer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_refs	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_refs;
typedef struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_nonrefs	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$refs	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$refs;
typedef struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$nonrefs	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$nonrefs;
typedef struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$object;

typedef struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$fields_struct	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$fields_struct;
typedef const struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$vmethods	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$vmethods;
typedef const struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtable	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtable;
typedef const struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtype	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtype;

// Class fields structure
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$fields_struct {
	struct _jc_java_lang_Object$object	*GRAY;
	jboolean	REVERSE;
};
extern _jc_soot_toolkits_graph_PseudoTopologicalOrderer$fields_struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$class_fields;

// Constructors
extern void _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_LinkedList$object *_jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$computeOrder$e99ef79fd26f3ec8(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$isReverseOrder$b4008fcd9aa94bc0(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$newList$4c736451834ee04d(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$setReverseOrder$f411ccc2da2c0b4c(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$visitNode$76904f2e0e29deb5(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method_info$computeOrder$e99ef79fd26f3ec8;
extern _jc_method _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method_info$isReverseOrder$b4008fcd9aa94bc0;
extern _jc_method _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method_info$newList$4c736451834ee04d;
extern _jc_method _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method_info$setReverseOrder$f411ccc2da2c0b4c;
extern _jc_method _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method_info$visitNode$76904f2e0e29deb5;

// Static methods
extern void _jc_soot_toolkits_graph_PseudoTopologicalOrderer$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$vmethods {
	struct _jc_java_util_LinkedList$object	*(*computeOrder$e99ef79fd26f3ec8)(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*isReverseOrder$b4008fcd9aa94bc0)(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*newList$4c736451834ee04d)(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setReverseOrder$f411ccc2da2c0b4c)(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, jboolean) _JC_JCNI_ATTR;
	void	(*visitNode$76904f2e0e29deb5)(_jc_env *, struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$vmethods	soot_toolkits_graph_PseudoTopologicalOrderer;
};

// Vtype
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_refs {
	struct _jc_object	*stmtToColor;
	struct _jc_java_util_LinkedList$object	*order;
	struct _jc_object	*graph;
	_jc_int_array	*indexStack;
	_jc_object_array	*stmtStack;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$refs {
    _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_refs	soot_toolkits_graph_PseudoTopologicalOrderer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_nonrefs {
	jboolean	mIsReversed;
	jint	last;
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_nonrefs	soot_toolkits_graph_PseudoTopologicalOrderer;
};

// Object instance structure
struct _jc_soot_toolkits_graph_PseudoTopologicalOrderer$object {
	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtype	*vtype;
	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_PseudoTopologicalOrderer$vtype _jc_soot_toolkits_graph_PseudoTopologicalOrderer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_PseudoTopologicalOrderer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_PseudoTopologicalOrderer$class_object;

#endif	/* _JC_soot_toolkits_graph_PseudoTopologicalOrderer_H_ */
